@@ -301,9 +301,16 @@ class Config(Object):
     ##
     def has_access(self,user):
         return self.managed_object.has_access(user)
-        
+    
     @classmethod
-    def queryset(cls,user):
+    def user_objects(cls, user):
+        """
+        Get objects available to user
+
+        :param user: User
+        :type user: User instance
+        :rtype: Queryset
+        """
         if user.is_superuser:
             return cls.objects.all()
         else:
@@ -357,6 +364,17 @@ class Config(Object):
                 return None
         return self.diff(old_data, new_data)
     
+    @property
+    def is_stale(self):
+        """
+        Check config is stale
+        """
+        if (self.managed_object.is_managed
+            and self.managed_object.is_configuration_managed):
+            now = datetime.datetime.now()
+            return self.last_pull is None or (now - self.last_pull).days >= 2
+        return False
+    
 
 ##
 ## PrefixList
@@ -479,6 +497,33 @@ class DNS(Object):
         for ns in nses.values():
             logging.debug("DNSHandler.global_push: provisioning %s"%ns.name)
             ns.provision_zones()
+    
+    ##
+    ## Override default notification order
+    ##
+    def get_notification_groups(self, immediately=False, delayed=False):
+        from noc.dns.models import DNSZone
+        # Try to assotiate with DNSZone
+        if not self.repo_path.endswith("autozones.conf")\
+                and os.sep in self.repo_path:
+            z = None
+            sn, zn = self.repo_path.split(os.sep, 1)
+            try:
+                z = DNSZone.objects.get(name=zn)
+            except DNSZone.DoesNotExist:
+                pass
+            if z:
+                # Zone found
+                if z.notification_group:
+                    # Return zone's notification group, if given
+                    return set([z.notification_group])
+                if z.profile.notification_group:
+                    # Return profile's notification_group, if given
+                    return set([z.profile.notification_group])
+        # Fall back to default notification group
+        return super(DNS, self).get_notification_groups(immediately=immediately, delayed=delayed)
+    
+
 ##
 ## RPSL
 ##
