@@ -39,6 +39,7 @@ class VRFGroup(models.Model):
     class Meta:
         verbose_name=_("VRF Group")
         verbose_name_plural=_("VRF Groups")
+        ordering = ["name"]
     
     name=models.CharField(_("VRF Group"),unique=True,max_length=64,help_text=_("Unique VRF Group name"))
     address_constraint=models.CharField(_("Address Constraint"),max_length=1,
@@ -60,6 +61,7 @@ class VRF(models.Model):
     class Meta:
         verbose_name=_("VRF")
         verbose_name_plural=_("VRFs")
+        ordering = ["name"]
     
     name=models.CharField(_("VRF"),unique=True,max_length=64,
         help_text=_("Unique VRF Name"))
@@ -203,6 +205,7 @@ class Prefix(models.Model):
         if not self.is_root:
             # Set proper parent
             self.parent=Prefix.get_parent(self.vrf,self.afi,self.prefix)
+        self.afi = "6" if ":" in self.prefix else "4"
         super(Prefix,self).save(**kwargs)
         # Rebuild tree if necessary
         # Reconnect children children prefixes
@@ -519,6 +522,8 @@ class Address(models.Model):
     ## Save address
     ##
     def save(self,**kwargs):
+        # Detect AFI
+        self.afi = "6" if ":" in self.address else "4"
         # Set proper prefix
         self.prefix=Prefix.get_parent(self.vrf,self.afi,self.address)
         super(Address,self).save(**kwargs)
@@ -580,6 +585,7 @@ class PrefixAccess(models.Model):
         verbose_name=_("Prefix Access")
         verbose_name_plural=_("Prefix Access")
         unique_together=[("user","vrf","afi","prefix")]
+        ordering = ["user", "vrf", "afi", "prefix"]
     
     user=models.ForeignKey(User,verbose_name=_("User"))
     vrf=models.ForeignKey(VRF,verbose_name=_("VRF"))
