@@ -7,13 +7,13 @@
 ##----------------------------------------------------------------------
 """
 """
-import noc.sa.periodic
+import noc.lib.periodic
 from noc.settings import config
 import os,subprocess,datetime
 import logging
 from tagging.models import TaggedItem
 
-class Task(noc.sa.periodic.Task):
+class Task(noc.lib.periodic.Task):
     name="main.cleanup"
     description="Obsolete data cleanup and system maintainance"
     
@@ -29,4 +29,18 @@ class Task(noc.sa.periodic.Task):
                 logging.info("Delete hanging tag reference: %s"%str(i))
                 i.delete()
         cursor.execute("COMMIT")
+        # Delete forgotten map/reduce tasks
+        cursor.execute("""
+            DELETE FROM sa_maptask
+            WHERE task_id IN (
+                SELECT id
+                FROM sa_reducetask
+                WHERE stop_time < ('now'::timestamp - '1day'::interval)
+            )
+        """)
+        cursor.execute("""
+            DELETE FROM sa_reducetask
+            WHERE stop_time < ('now'::timestamp - '1day'::interval)
+        """)
+        cursor.execute("COMMIT")
         return True
