@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 ##----------------------------------------------------------------------
+## Alcatel.AOS.get_config
+##----------------------------------------------------------------------
 ## Copyright (C) 2007-2009 The NOC Project
 ## See LICENSE for details
 ##----------------------------------------------------------------------
@@ -12,5 +14,5 @@ class Script(noc.sa.script.Script):
     name="Alcatel.AOS.get_config"
     implements=[IGetConfig]
     def execute(self):
-        config=self.cli("show running-config")
+        config=self.cli("show configuration snapshot")
         return self.cleaned_config(config)
