@@ -130,8 +130,18 @@ class Script(NOCScript):
                     print "\n\n\n\n\nremote_port_id\n\n\n\n\n"
                     continue
                 n["remote_port"] = match.group("port").strip()
-                # On DES-3028/52 Series "Port ID" may be typed like
-                # "RMON Port 28 on Unit 1"
+                '''
+                Possible variants of Port ID, if Remote Port ID is "Local":
+                Big thanks to D-Link developers :)
+                >>> DGS-3100 Series
+                1:2
+                >>> DES-3526/3550 Series
+                1/2
+                >>> DES-3028/3052 Series
+                RMON Port 2 on Unit 1
+                >>> Other switches
+                2
+                '''
                 if n["remote_port_subtype"] == 7 \
                 and n["remote_port"].lower().startswith("rmon port"):
                     match=self.rx_remote_port_id2.search(n["remote_port"])
