@@ -11,6 +11,7 @@ from noc.sa.script import Script as NOCScript
 from noc.sa.interfaces import IGetMACAddressTable
 from noc.sa.profiles.DLink.DxS import DES3200
 from noc.sa.profiles.DLink.DxS import DGS3100
+from noc.sa.profiles.DLink.DxS import DGS3120
 from noc.sa.profiles.DLink.DxS import DGS3400
 from noc.sa.profiles.DLink.DxS import DGS3600
 import re
@@ -28,6 +29,7 @@ class Script(NOCScript):
         if vlan is not None:
             if self.match_version(DES3200, version__gte="1.33") \
             or self.match_version(DGS3100, version__gte="3.60.30") \
+            or self.match_version(DGS3120, version__gte="1.00.28") \
             or self.match_version(DGS3400, version__gte="2.70") \
             or self.match_version(DGS3600, version__gte="2.52"):
                 cmd+=" vlanid %d"%vlan
