@@ -2,9 +2,8 @@
 ##----------------------------------------------------------------------
 ## Vendor: Zyxel
 ## OS:     ZyNOS
-## Compatible: 3124
 ##----------------------------------------------------------------------
-## Copyright (C) 2007-2009 The NOC Project
+## Copyright (C) 2007-2011 The NOC Project
 ## See LICENSE for details
 ##----------------------------------------------------------------------
 """
@@ -17,6 +16,12 @@ class Profile(noc.sa.profiles.Profile):
     supported_schemes=[TELNET,SSH]
     pattern_username="User name:"
     pattern_unpriveleged_prompt=r"^\S+?>"
-    command_super="enable"
     pattern_prompt=r"^\S+?#"
+    pattern_more=r"^-- more --.*?$" 
+    command_super="enable"
     command_more=" "
+    command_enter_config="configure" 
+    command_leave_config="exit" 
+    command_exit="exit" 
+    command_save_config="write memory" 
+    pattern_syntax_error="Invalid command"
