@@ -15,11 +15,15 @@ class Profile(noc.sa.profiles.Profile):
     name="f5.BIGIP"
     supported_schemes=[SSH]
     pattern_username="^([Uu]sername|[Ll]ogin):"
-    pattern_prompt="bp>"
+    pattern_prompt=r"^(\[(?P<hostprompt>[^\]]+)\]\s\S+\s#\s)|(.+?\(tmos\)# )"
     pattern_more=[
             (r"^(/var/tmp/shell\.out\.\S+|:)"," "),
             (r"^\(END\) ","q"),
+            (r"^Display all \d+ items\? \(y/n\)\s+", "y"),
+            (r"^---\(less \d+%\)---", " "),
+            (r"^\(END\)", "q"),
             ]
+    
     def cleaned_input(self,input):
         input=input.replace("\x1b[24;1H\x1b[K","\n")
         return super(Profile,self).cleaned_input(input)
