@@ -215,11 +215,14 @@ class Script(threading.Thread):
     # For common scripts - empty list
     # For generics - list of pairs (script_name, interface)
     requires=[]
+    #
+    template = None  # Relative template path in sa/templates/
     # Constants
     TELNET=TELNET
     SSH=SSH
     HTTP=HTTP
     TIMEOUT=120 # 2min by default
+    CLI_TIMEOUT = None # Optional timeout for telnet/ssh providers
     #
     LoginError=LoginError
     CLISyntaxError=CLISyntaxError
@@ -228,16 +231,12 @@ class Script(threading.Thread):
     #
     _execute_chain=[]
 
-    def __init__(self, profile, activator, access_profile, timeout=0, parent=None, **kwargs):
+    def __init__(self, profile, _activator, access_profile, timeout=0, parent=None, **kwargs):
         self.start_time=time.time()
         self.parent=parent
         self.access_profile=access_profile
         self.attrs={}
         self._timeout=timeout if timeout else self.TIMEOUT
-        for a in access_profile.attrs:
-            self.attrs[a.key]=a.value
-        import logging
-        logging.debug(repr(self.attrs))
         if self.access_profile.address:
             p=self.access_profile.address
         elif self.access_profile.path:
@@ -245,12 +244,25 @@ class Script(threading.Thread):
         else:
             p="<unknown>"
         self.debug_name="script-%s-%s"%(p, self.name)
+        self.encoding = None # Device encoding. None if UTF8
+        for a in access_profile.attrs:
+            self.attrs[a.key]=a.value
+            # Try to get encoding from attributes
+            if a.key == "encoding":
+                v = a.value.strip()
+                # Test encoding
+                try:
+                    u"test".encode(v)
+                    self.encoding = v
+                    self.debug("Using '%s' encoding" % v)
+                except LookupError:
+                    self.error("Unknown encoding: '%s'" % v)
         super(Script, self).__init__(name=self.debug_name, kwargs=kwargs)
-        self.activator=activator
-        self.servers=activator.servers
+        self.activator=_activator
+        self.servers=_activator.servers
         self.profile=profile
         self.cli_provider=None
-        self.http=HTTPProvider(self.access_profile)
+        self.http=HTTPProvider(self)
         self.snmp=SNMPProvider(self)
         self.status=False
         self.result=None
@@ -267,8 +279,9 @@ class Script(threading.Thread):
         self.e_timeout=False # Script terminated with timeout
         self.e_cancel=False # Scrcipt cancelled
         self.e_not_supported=False # NotSupportedError risen
+        self.e_http_error = False # HTTPError risen
         self._thread_id=None # Python 2.5 compatibility
-        
+        # Set up CLI session logging
         if self.parent:
             self.log_cli_sessions_path=self.parent.log_cli_sessions_path
         elif self.activator.log_cli_sessions\
@@ -282,6 +295,30 @@ class Script(threading.Thread):
                 self.log_cli_sessions_path=self.log_cli_sessions_path.replace("{{%s}}"%k, v)
             self.cli_debug("IP: %s SCRIPT: %s"%(self.access_profile.address, self.name),"!")
     
+    @classmethod
+    def template_clean_result(cls, result):
+        """
+        Clean result to render template
+        """
+        if self.implements:
+            return cls.implements[0].template_clean_result(cls.profile, result)
+        else:
+            return result
+    
+    @classmethod
+    def get_template(cls):
+        """
+        Get template path.
+        
+        :return: Template path or None
+        :rtype: String or None
+        """
+        if cls.template:
+            return template
+        if cls.implements and cls.implements[0].template:
+            return cls.implements[0].template
+        return None
+    
     ##
     ## Compile arguments into version check function
     ## Returns callable accepting self and version hash arguments
@@ -395,13 +432,13 @@ class Script(threading.Thread):
     ## Debug log message
     ##
     def debug(self, msg):
-        logging.debug("[%s] %s"%(self.debug_name, msg))
+        logging.debug(u"[%s] %s"%(self.debug_name, unicode(str(msg), "utf8")))
     
     ##
     ## Error log message
     ##
     def error(self, msg):
-        logging.error("[%s] %s"%(self.debug_name, msg))
+        logging.error(u"[%s] %s"%(self.debug_name, unicode(str(msg), "utf8")))
     
     ##
     ## Return root script
@@ -487,6 +524,9 @@ class Script(threading.Thread):
         except self.LoginError, why:
             self.login_error=why.args[0]
             self.error("Login failed: %s"%self.login_error)
+        except self.http.HTTPError, e:
+            self.error(str(e))
+            self.e_http_error = str(e)
         except:
             if self.e_cancel:
                 # Race condition caught. Handle CancelledError
@@ -498,6 +538,10 @@ class Script(threading.Thread):
                 self.error_traceback="\n".join(r)
                 self.debug("Script traceback:\n%s"%self.error_traceback)
         else:
+            # Shutdown session
+            if self.profile.shutdown_session and not self.activator.use_canned_session:
+                self.debug("Shutting down session")
+                self.profile.shutdown_session(self)
             # Serialize result
             self.result=self.serialize_result(result)
             if self.parent is None and self.need_to_save and self.profile.command_save_config:
@@ -560,11 +604,11 @@ class Script(threading.Thread):
                 s_class=CLISSHSocket
             else:
                 raise UnknownAccessScheme(self.access_profile.scheme)
-            self.cli_provider=s_class(self.activator.factory, self.profile, self.access_profile) #@todo: pass activator
+            self.cli_provider=s_class(self)
             self.cli_queue_get()
             self.debug("CLI Provider is ready")
             # Set up session when necessary
-            if self.profile.setup_session:
+            if self.profile.setup_session and not self.activator.use_canned_session:
                 self.debug("Setting up session")
                 self.profile.setup_session(self)
             # Disable pager when necessary
@@ -591,6 +635,9 @@ class Script(threading.Thread):
             self.request_cli_provider()
             self.cli_provider.submit(cmd, command_submit=command_submit, bulk_lines=bulk_lines)
             data=self.cli_queue_get()
+        # Encode to UTF8 if requested
+        if self.encoding:
+            data = unicode(data, self.encoding).encode("utf8")
         # Save canned output if requested
         if self.activator.to_save_output:
             self.activator.save_interaction("cli", cmd, data)
