@@ -90,6 +90,7 @@ MSG_CHANNEL_DATA = 94
 MSG_CHANNEL_EXTENDED_DATA = 95
 MSG_CHANNEL_REQUEST = 98
 MSG_CHANNEL_SUCCESS = 99
+MSG_CHANNEL_FAILURE = 100
 
 DISCONNECT_HOST_NOT_ALLOWED_TO_CONNECT = 1
 DISCONNECT_PROTOCOL_ERROR = 2
@@ -136,10 +137,11 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
     SSH_AUTH_METHODS=["publickey", "password", "keyboard-interactive", "none"]
     
     rx_ssh_version=re.compile(r"^SSH-(?P<version>\d+\.\d+)-(?P<soft>.+$)")
-    def __init__(self, factory, profile, access_profile):
-        self._log_label="SSH: %s"%access_profile.address
-        CLI.__init__(self, profile, access_profile)
-        port=access_profile.port or 22
+    def __init__(self, script):
+        self.script = script
+        self._log_label = "SSH: %s" % self.script.access_profile.address
+        CLI.__init__(self, self.script.profile, self.script.access_profile)
+        port = self.script.access_profile.port or 22
         self.transform=None # current SSH Transform
         self.next_transform=None
         self.in_seq=0
@@ -163,7 +165,16 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
         self.last_auth=None
         self.authenticated_with=set()
         self.out_data_buffer=""
-        ConnectedTCPSocket.__init__(self, factory, access_profile.address, port)
+        ConnectedTCPSocket.__init__(self, self.script.activator.factory,
+            self.script.access_profile.address, port)
+        if self.script.CLI_TIMEOUT:
+            ConnectedTCPSocket.set_timeout(self, self.script.CLI_TIMEOUT)
+    
+    ##
+    ##
+    ##
+    def dump_data(self, data):
+        return " ".join(["%02X"%ord(c) for c in data])
     
     ##
     ## Received data dispatcher
@@ -180,7 +191,9 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
                 try:
                     h=self.SSH_MESSAGES[msg_type]
                 except KeyError:
-                    self.error("Uniplemented packet type: %d"%msg_type)
+                    self.error("Uniplemented packet type: %d (%s %s)" % (
+                                                msg_type, self.dump_data(p),
+                                                repr(p)))
                     self.send_uniplemented()
                     continue
                 self.debug("Receiving message type %s (%d)"%(msg_names[msg_type], msg_type))
@@ -226,7 +239,7 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
     ##
     def is_stale(self):
         if self.get_state()=="PROMPT":
-            self.async_check_fsm() 
+            self.async_check_fsm()
         return ConnectedTCPSocket.is_stale(self)
     
     ##
@@ -247,6 +260,14 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
     def error(self, msg):
         logging.error("[%s] %s"%(self.log_label(),msg))
     
+    ##
+    ##
+    ##
+    def on_close(self):
+        if self.get_state() == "SSH_START":
+            self.motd = "Connection timeout"
+            self.set_state("FAILURE")
+    
     ##
     def generate_private_x(self, bits):
         def get_random(bits):
@@ -389,7 +410,8 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
             self.debug("Authenticating with '%s' method"%m)
             getattr(self,"request_auth_%s"%m.replace("-", "_"))() # Request authentication method
         else:
-            self.send_disconnect(DISCONNECT_NO_MORE_AUTH_METHODS_AVAILABLE, "No more authentication methods available")
+            self.send_disconnect(DISCONNECT_NO_MORE_AUTH_METHODS_AVAILABLE,
+                                 "No more authentication methods available")
     
     ##
     ##
@@ -853,13 +875,18 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
         name, instruction, lang, data = get_NS(packet, 3)
         n_prompts = struct.unpack('!L', data[:4])[0]
         data = data[4:]
-        prompts=[]
+        prompts = []
         for i in range(n_prompts):
-            s, data=get_NS(data, 1)
-            prompts+=[(s, bool(ord(data[0])))]
-            data=data[1:]
-        responses=[self.access_profile.password]
-        data=struct.pack("!L", len(responses))
+            s, data = get_NS(data, 1)
+            prompts += [(s, bool(ord(data[0])))]
+            data = data[1:]
+        self.debug("keyboard-interactive instruction: %s" % instruction)
+        self.debug("keyboard-interactive prompts: %s" % str(prompts))
+        if prompts:
+            responses = [self.access_profile.password]
+        else:
+            responses = []
+        data = struct.pack("!L", len(responses))
         for r in responses:
             data += NS(r.encode("utf8"))
         self.send_packet(MSG_USERAUTH_INFO_RESPONSE, data)
@@ -901,6 +928,24 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
         self.remote_window_left += bytes_to_add
         self.flush_data_buffer()
     
+    ##
+    ## MSG_CHANNEL_REQUEST
+    ## Payload:
+    ##     uint32 channel_id
+    ##     string request type
+    ##     bool   want reply
+    ##
+    def ssh_CHANNEL_REQUEST(self, packet):
+        channel_id, = struct.unpack(">L", packet[:4]) # @todo: Check local channel id
+        request_type, rest = get_NS(packet[4:])
+        want_reply = bool(ord(rest[0]))
+        if not want_reply:
+            return
+        # Process keepalives
+        if request_type.startswith("keepalive@"):
+            self.send_packet(MSG_CHANNEL_FAILURE,
+                struct.pack(">2L", self.current_remote_channel, 0))
+    
     ##
     ## MSG_CHANNEL_SUCCESS
     ##
@@ -970,6 +1015,7 @@ class CLISSHSocket(CLI, ConnectedTCPSocket):
         MSG_CHANNEL_OPEN_CONFIRMATION : ssh_CHANNEL_OPEN_CONFIRMATION,
         MSG_CHANNEL_OPEN_FAILURE      : ssh_CHANNEL_OPEN_FAILURE,
         MSG_CHANNEL_WINDOW_ADJUST     : ssh_CHANNEL_WINDOW_ADJUST,
+        MSG_CHANNEL_REQUEST           : ssh_CHANNEL_REQUEST,
         MSG_CHANNEL_SUCCESS           : ssh_CHANNEL_SUCCESS,
     }
 
